from django.urls import reverse
from rest_framework import status

from arkindex.process.models import WorkerType
from arkindex.project.tests import FixtureAPITestCase


class TestWorkersWorkerTypes(FixtureAPITestCase):
    """
    Test workers and worker versions endpoints
    """

    @classmethod
    def setUpTestData(cls):
        super().setUpTestData()
        cls.worker_type_dla = WorkerType.objects.get(slug="dla")
        cls.worker_type_recognizer = WorkerType.objects.get(slug="recognizer")
        cls.worker_type_worker = WorkerType.objects.get(slug="worker")
        cls.worker_type_import = WorkerType.objects.get(slug="import")
        cls.worker_type_custom = WorkerType.objects.get(slug="custom")
        cls.init_type = WorkerType.objects.get(slug="init")

    def test_list_worker_types(self):
        # An un-authenticated user has access to worker types
        with self.assertNumQueries(2):
            response = self.client.get(reverse("api:worker-type-list"))
            self.assertEqual(response.status_code, status.HTTP_200_OK)

        self.assertDictEqual(response.json(), {
            "count": 6,
            "previous": None,
            "next": None,
            "number": 1,
            "results": [
                {
                    "display_name": "Custom",
                    "id": str(self.worker_type_custom.id),
                    "slug": "custom",
                },
                {
                    "id": str(self.worker_type_dla.id),
                    "slug": "dla",
                    "display_name": "Document Layout Analysis",
                },
                {
                    "id": str(self.init_type.id),
                    "slug": "init",
                    "display_name": "Elements Initialisation",
                },
                {
                    "id": str(self.worker_type_import.id),
                    "slug": "import",
                    "display_name": "Import",
                },
                {
                    "id": str(self.worker_type_recognizer.id),
                    "slug": "recognizer",
                    "display_name": "Recognizer",
                },
                {
                    "id": str(self.worker_type_worker.id),
                    "slug": "worker",
                    "display_name": "Worker requiring a GPU",
                },
            ],
        })
